@@ -47,12 +47,14 @@ ContactToolTip::ContactToolTip(const QModelIndex &index) :
     QPixmap avatarPixmap(qvariant_cast<QPixmap>(index.data(KTp::ContactAvatarPixmapRole)));
     ui->avatarLabel->setPixmap(avatarPixmap.scaled(ui->avatarLabel->size(), Qt::KeepAspectRatio));
 
-    QString presenceMessage = index.data(KTp::ContactPresenceMessageRole).toString();
-    QString presenceIconPath = index.data(KTp::ContactPresenceIconRole).toString();
-    QString presenceText = index.data(KTp::ContactPresenceNameRole).toString();
+    KTp::Presence presence(Tp::Presence((Tp::ConnectionPresenceType)index.data(KTp::ContactPresenceTypeRole).toUInt(),
+                                        QString(), //the presence name is not needed, saves one call to the model
+                                        index.data(KTp::ContactPresenceMessageRole).toString()));
+
+    QString presenceMessage = presence.statusMessage();
+    QString presenceText = presence.displayString();
 
     if (index.data(KTp::ContactPresenceTypeRole).toInt() == Tp::ConnectionPresenceTypeError) {
-        presenceIconPath = KIconLoader::global()->iconPath("task-attention", 1);
         presenceText = i18nc("This is an IM user status", "Error Getting Presence");
 
         /** if the presence is error, the message might containt server's error,
@@ -62,7 +64,9 @@ ContactToolTip::ContactToolTip(const QModelIndex &index) :
         presenceMessage.clear();
     }
 
-    ui->presenceIcon->setPixmap(QPixmap(presenceIconPath));
+    int smallIconSize = KIconLoader::global()->currentSize(KIconLoader::Small);
+
+    ui->presenceIcon->setPixmap(presence.icon().pixmap(smallIconSize, smallIconSize));
     ui->presenceLabel->setText(presenceText);
     ui->presenceMessageLabel->setText(presenceMessage);
     ui->blockedLabel->setShown(index.data(KTp::ContactIsBlockedRole).toBool());
@@ -110,4 +114,4 @@ QString ContactToolTip::getTextWithHyperlinks(QString text)
     }
 
     return result;
-}
\ No newline at end of file
+}
